==> puppet-module-neutron_19.4.0.orig.tar.xz: puppet-module-neutron-19.4.0/spec/classes/neutron_policy_spec.rb <==
require 'spec_helper'

describe 'neutron::policy' do
  shared_examples 'neutron::policy' do

    context 'setup policy with parameters' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/neutron/policy.yaml',
          :policy_dirs          => '/etc/neutron/policy.d',
          :policies             => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          }
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/neutron/policy.yaml').with(
          :policies     => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          },
          :policy_path  => '/etc/neutron/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'neutron',
          :file_format  => 'yaml',
          :purge_config => false,
        )
        is_expected.to contain_oslo__policy('neutron_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/neutron/policy.yaml',
          :policy_dirs          => '/etc/neutron/policy.d',
        )
      end
    end

    context 'with empty policies and purge_config enabled' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/neutron/policy.yaml',
          :policies             => {},
          :purge_config         => true,
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/neutron/policy.yaml').with(
          :policies     => {},
          :policy_path  => '/etc/neutron/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'neutron',
          :file_format  => 'yaml',
          :purge_config => true,
        )
        is_expected.to contain_oslo__policy('neutron_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/neutron/policy.yaml',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'neutron::policy'
    end
  end
end

==> puppet-module-neutron_23.0.0.orig.tar.xz: puppet-module-neutron-23.0.0/spec/classes/neutron_policy_spec.rb <==
require 'spec_helper'

describe 'neutron::policy' do
  shared_examples 'neutron::policy' do

    context 'setup policy with parameters' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/neutron/policy.yaml',
          :policy_default_rule  => 'default',
          :policy_dirs          => '/etc/neutron/policy.d',
          :policies             => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          }
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/neutron/policy.yaml').with(
          :policies     => {
            'context_is_admin' => {
              'key'   => 'context_is_admin',
              'value' => 'foo:bar'
            }
          },
          :policy_path  => '/etc/neutron/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'neutron',
          :file_format  => 'yaml',
          :purge_config => false,
          :tag          => 'neutron',
        )
        is_expected.to contain_oslo__policy('neutron_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/neutron/policy.yaml',
          :policy_default_rule  => 'default',
          :policy_dirs          => '/etc/neutron/policy.d',
        )
      end
    end

    context 'with empty policies and purge_config enabled' do
      let :params do
        {
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_path          => '/etc/neutron/policy.yaml',
          :policies             => {},
          :purge_config         => true,
        }
      end

      it 'set up the policies' do
        is_expected.to contain_openstacklib__policy('/etc/neutron/policy.yaml').with(
          :policies     => {},
          :policy_path  => '/etc/neutron/policy.yaml',
          :file_user    => 'root',
          :file_group   => 'neutron',
          :file_format  => 'yaml',
          :purge_config => true,
          :tag          => 'neutron',
        )
        is_expected.to contain_oslo__policy('neutron_config').with(
          :enforce_scope        => false,
          :enforce_new_defaults => false,
          :policy_file          => '/etc/neutron/policy.yaml',
        )
      end
    end
  end

  on_supported_os({
    :supported_os => OSDefaults.get_supported_os
  }).each do |os,facts|
    context "on #{os}" do
      let (:facts) do
        facts.merge!(OSDefaults.get_facts())
      end

      it_behaves_like 'neutron::policy'
    end
  end
end
